##################################################################################################
### Eurasia script for publication
### last modified: 31. August 2018



##################################################################################################
### table of contents
# (I)	load packages
# (II)	load climate data
# (III)	calculate P-PET (water balance)
# (IV)	calculate April-July mean of P-PET (water balance), TEMP and PREC; correlate P-PET with TEMP and PREC
# (V)	calculate TEMP_JA, extract years from TEMP_JA that belong to the two climate regimes
# (VI)	load tree-ring data per site and proxy, standardize, and synchronize IDs 
# (VII)	climate-growth correlations for climate regimes using site chronologies: MXD
# (VIII)climate-growth correlations for climate regimes using individual trees: MXD~T_JA
# (IX)	climate-growth correlations for climate regimes using site chronologies: TRW
# (X)	climate-growth correlations for climate regimes using individual trees: TRW~Temp of year of growth
# (XI)	Wilcoxon rank-sum test for significant difference
# (XII)	plot Figures 3 and 4




# site abbreviations used in this script:
# K: FIN treeline
# L: FIN forest
# U: RUS treeline
# O: RUS forest
# H: SIB treeline
# G: SIB forest
# 1: dry (e.g. K1)
# 2: wet (e.g. K2)



##################################################################################################
# (I)	load packages

library(SPEI)
library(dplR)
library(treeclim)




##################################################################################################
# (II)	load climate data

# format of climate data: years in rows, months in columns. Years in 1st column. 

# set working directory 
#setwd("")

K_TEMP<-read.table("K_TEMP_CRU.txt")
K_PREC<-read.table("K_PREC_CRU.txt")

L_TEMP<-read.table("L_TEMP_CRU.txt")
L_PREC<-read.table("L_PREC_CRU.txt")

U_TEMP<-read.table("U_TEMP_CRU.txt")
U_PREC<-read.table("U_PREC_CRU.txt")

O_TEMP<-read.table("O_TEMP_CRU.txt")
O_PREC<-read.table("O_PREC_CRU.txt")

H_TEMP<-read.table("H_TEMP_CRU.txt")
H_PREC<-read.table("H_PREC_CRU.txt")

G_TEMP<-read.table("G_TEMP_CRU.txt")
G_PREC<-read.table("G_PREC_CRU.txt")





##################################################################################################
# (III)	calculate P-PET (water balance)


# K
# delete 1st column and vectorize temperature
T_MATR<-as.matrix(K_TEMP[,-1])
T_VEC<-vector(mode="numeric")
for(i in 1:113)
{
T_VEC[((i-1)*12+1):(i*12)]<-
T_MATR[i,]
}

# PET
K_PET<-as.numeric(print(thornthwaite(T_VEC,70))) # insert latitude

# make matrix
K_PET_MAT<-matrix(nrow=113,ncol=12)
for(i in 1:113)
{
K_PET_MAT[i,]<-
K_PET[((i-1)*12+1):(i*12)]
}

# P-PET
K_PPET<-K_PREC[,-1]-K_PET_MAT



# L
# delete 1st column and vectorize temperature
T_MATR<-as.matrix(L_TEMP[,-1])
T_VEC<-vector(mode="numeric")
for(i in 1:113)
{
T_VEC[((i-1)*12+1):(i*12)]<-
T_MATR[i,]
}

# PET
L_PET<-as.numeric(print(thornthwaite(T_VEC,69))) # insert latitude

# make matrix
L_PET_MAT<-matrix(nrow=113,ncol=12)
for(i in 1:113)
{
L_PET_MAT[i,]<-
L_PET[((i-1)*12+1):(i*12)]
}

# P-PET
L_PPET<-L_PREC[,-1]-L_PET_MAT



# U
# delete 1st column and vectorize temperature
T_MATR<-as.matrix(U_TEMP[,-1])
T_VEC<-vector(mode="numeric")
for(i in 1:113)
{
T_VEC[((i-1)*12+1):(i*12)]<-
T_MATR[i,]
}

# PET
U_PET<-as.numeric(print(thornthwaite(T_VEC,66))) # insert latitude

# make matrix
U_PET_MAT<-matrix(nrow=113,ncol=12)
for(i in 1:113)
{
U_PET_MAT[i,]<-
U_PET[((i-1)*12+1):(i*12)]
}

# P-PET
U_PPET<-U_PREC[-114,-1]-U_PET_MAT



# O
# delete 1st column and vectorize temperature
T_MATR<-as.matrix(O_TEMP[,-1])
T_VEC<-vector(mode="numeric")
for(i in 1:113)
{
T_VEC[((i-1)*12+1):(i*12)]<-
T_MATR[i,]
}

# PET
O_PET<-as.numeric(print(thornthwaite(T_VEC,65))) # insert latitude

# make matrix
O_PET_MAT<-matrix(nrow=113,ncol=12)
for(i in 1:113)
{
O_PET_MAT[i,]<-
O_PET[((i-1)*12+1):(i*12)]
}

# P-PET
O_PPET<-O_PREC[-114,-1]-O_PET_MAT



# H
# delete 1st column and vectorize temperature
T_MATR<-as.matrix(H_TEMP[,-1])
T_VEC<-vector(mode="numeric")
for(i in 1:113)
{
T_VEC[((i-1)*12+1):(i*12)]<-
T_MATR[i,]
}

# PET
H_PET<-as.numeric(print(thornthwaite(T_VEC,65))) # insert latitude

# make matrix
H_PET_MAT<-matrix(nrow=113,ncol=12)
for(i in 1:113)
{
H_PET_MAT[i,]<-
H_PET[((i-1)*12+1):(i*12)]
}

# P-PET
H_PPET<-H_PREC[-c(114,115),-1]-H_PET_MAT



# G
# delete 1st column and vectorize temperature
T_MATR<-as.matrix(G_TEMP[,-1])
T_VEC<-vector(mode="numeric")
for(i in 1:113)
{
T_VEC[((i-1)*12+1):(i*12)]<-
T_MATR[i,]
}

# PET
G_PET<-as.numeric(print(thornthwaite(T_VEC,64))) # insert latitude

# make matrix
G_PET_MAT<-matrix(nrow=113,ncol=12)
for(i in 1:113)
{
G_PET_MAT[i,]<-
G_PET[((i-1)*12+1):(i*12)]
}

# P-PET
G_PPET<-G_PREC[-c(114,115),-1]-G_PET_MAT






##################################################################################################
# (IV)	calculate April-July mean of P-PET (water balance), TEMP and PREC; correlate P-PET with TEMP and PREC


# K 
K_PPET_GROWING_single<-K_PPET[1:113,c(4:7)]
K_PPET_GROWING<-vector(mode="numeric")
for(i in 1:nrow(K_PPET_GROWING_single))
{
K_PPET_GROWING[i]<-
mean(as.matrix(K_PPET_GROWING_single[i,]))
}

K_TEMP_GROWING_single<-K_TEMP[1:113,c(5:8)]
K_TEMP_GROWING<-vector(mode="numeric")
for(i in 1:nrow(K_TEMP_GROWING_single))
{
K_TEMP_GROWING[i]<-
mean(as.matrix(K_TEMP_GROWING_single[i,]))
}

cor.test(K_TEMP_GROWING,K_PPET_GROWING)

K_PREC_GROWING_single<-K_PREC[1:113,c(5:8)]
K_PREC_GROWING<-vector(mode="numeric")
for(i in 1:nrow(K_PREC_GROWING_single))
{
K_PREC_GROWING[i]<-
mean(as.matrix(K_PREC_GROWING_single[i,]))
}

cor.test(K_PREC_GROWING,K_PPET_GROWING)



# L 
L_PPET_GROWING_single<-L_PPET[1:113,c(4:7)]
L_PPET_GROWING<-vector(mode="numeric")
for(i in 1:nrow(L_PPET_GROWING_single))
{
L_PPET_GROWING[i]<-
mean(as.matrix(L_PPET_GROWING_single[i,]))
}

L_TEMP_GROWING_single<-L_TEMP[1:113,c(5:8)]
L_TEMP_GROWING<-vector(mode="numeric")
for(i in 1:nrow(L_TEMP_GROWING_single))
{
L_TEMP_GROWING[i]<-
mean(as.matrix(L_TEMP_GROWING_single[i,]))
}

cor.test(L_TEMP_GROWING,L_PPET_GROWING)

L_PREC_GROWING_single<-L_PREC[1:113,c(5:8)]
L_PREC_GROWING<-vector(mode="numeric")
for(i in 1:nrow(L_PREC_GROWING_single))
{
L_PREC_GROWING[i]<-
mean(as.matrix(L_PREC_GROWING_single[i,]))
}

cor.test(L_PREC_GROWING,L_PPET_GROWING)



# U 
U_PPET_GROWING_single<-U_PPET[1:113,c(4:7)]
U_PPET_GROWING<-vector(mode="numeric")
for(i in 1:nrow(U_PPET_GROWING_single))
{
U_PPET_GROWING[i]<-
mean(as.matrix(U_PPET_GROWING_single[i,]))
}

U_TEMP_GROWING_single<-U_TEMP[1:113,c(5:8)]
U_TEMP_GROWING<-vector(mode="numeric")
for(i in 1:nrow(U_TEMP_GROWING_single))
{
U_TEMP_GROWING[i]<-
mean(as.matrix(U_TEMP_GROWING_single[i,]))
}

cor.test(U_TEMP_GROWING,U_PPET_GROWING)

U_PREC_GROWING_single<-U_PREC[1:113,c(5:8)]
U_PREC_GROWING<-vector(mode="numeric")
for(i in 1:nrow(U_PREC_GROWING_single))
{
U_PREC_GROWING[i]<-
mean(as.matrix(U_PREC_GROWING_single[i,]))
}

cor.test(U_PREC_GROWING,U_PPET_GROWING)



# O 
O_PPET_GROWING_single<-O_PPET[1:113,c(4:7)]
O_PPET_GROWING<-vector(mode="numeric")
for(i in 1:nrow(O_PPET_GROWING_single))
{
O_PPET_GROWING[i]<-
mean(as.matrix(O_PPET_GROWING_single[i,]))
}

O_TEMP_GROWING_single<-O_TEMP[1:113,c(5:8)]
O_TEMP_GROWING<-vector(mode="numeric")
for(i in 1:nrow(O_TEMP_GROWING_single))
{
O_TEMP_GROWING[i]<-
mean(as.matrix(O_TEMP_GROWING_single[i,]))
}

cor.test(O_TEMP_GROWING,O_PPET_GROWING)

O_PREC_GROWING_single<-O_PREC[1:113,c(5:8)]
O_PREC_GROWING<-vector(mode="numeric")
for(i in 1:nrow(O_PREC_GROWING_single))
{
O_PREC_GROWING[i]<-
mean(as.matrix(O_PREC_GROWING_single[i,]))
}

cor.test(O_PREC_GROWING,O_PPET_GROWING)



# H 
H_PPET_GROWING_single<-H_PPET[1:113,c(4:7)]
H_PPET_GROWING<-vector(mode="numeric")
for(i in 1:nrow(H_PPET_GROWING_single))
{
H_PPET_GROWING[i]<-
mean(as.matrix(H_PPET_GROWING_single[i,]))
}

H_TEMP_GROWING_single<-H_TEMP[1:113,c(5:8)]
H_TEMP_GROWING<-vector(mode="numeric")
for(i in 1:nrow(H_TEMP_GROWING_single))
{
H_TEMP_GROWING[i]<-
mean(as.matrix(H_TEMP_GROWING_single[i,]))
}

cor.test(H_TEMP_GROWING,H_PPET_GROWING)

H_PREC_GROWING_single<-H_PREC[1:113,c(5:8)]
H_PREC_GROWING<-vector(mode="numeric")
for(i in 1:nrow(H_PREC_GROWING_single))
{
H_PREC_GROWING[i]<-
mean(as.matrix(H_PREC_GROWING_single[i,]))
}

cor.test(H_PREC_GROWING,H_PPET_GROWING)



# G 
G_PPET_GROWING_single<-G_PPET[1:113,c(4:7)]
G_PPET_GROWING<-vector(mode="numeric")
for(i in 1:nrow(G_PPET_GROWING_single))
{
G_PPET_GROWING[i]<-
mean(as.matrix(G_PPET_GROWING_single[i,]))
}

G_TEMP_GROWING_single<-G_TEMP[1:113,c(5:8)]
G_TEMP_GROWING<-vector(mode="numeric")
for(i in 1:nrow(G_TEMP_GROWING_single))
{
G_TEMP_GROWING[i]<-
mean(as.matrix(G_TEMP_GROWING_single[i,]))
}

cor.test(G_TEMP_GROWING,G_PPET_GROWING)

G_PREC_GROWING_single<-G_PREC[1:113,c(5:8)]
G_PREC_GROWING<-vector(mode="numeric")
for(i in 1:nrow(G_PREC_GROWING_single))
{
G_PREC_GROWING[i]<-
mean(as.matrix(G_PREC_GROWING_single[i,]))
}

cor.test(G_PREC_GROWING,G_PPET_GROWING)








##################################################################################################
# (V)	calculate TEMP_JA, extract years from TEMP_JA that belong to the two climate regimes


# K 
K_TEMP_JA_single<-K_TEMP[1:113,c(8:9)]
K_TEMP_JA<-vector(mode="numeric")
for(i in 1:nrow(K_TEMP_JA_single))
{
K_TEMP_JA[i]<-
mean(as.matrix(K_TEMP_JA_single[i,]))
}

# upper quartile (25% coldest/wettest)
K_TEMP_JA_POSPPET<-K_TEMP_JA[which(K_PPET_GROWING>quantile(K_PPET_GROWING)[4])]
# lower quartile (25% driest/warmest)
K_TEMP_JA_NEGPPET<-K_TEMP_JA[which(K_PPET_GROWING<quantile(K_PPET_GROWING)[2])]

mean(K_TEMP_JA_POSPPET)
mean(K_TEMP_JA_NEGPPET)


# L
L_TEMP_JA_single<-L_TEMP[1:113,c(8:9)]
L_TEMP_JA<-vector(mode="numeric")
for(i in 1:nrow(L_TEMP_JA_single))
{
L_TEMP_JA[i]<-
mean(as.matrix(L_TEMP_JA_single[i,]))
}

# upper quartile (25% coldest/wettest)
L_TEMP_JA_POSPPET<-L_TEMP_JA[which(L_PPET_GROWING>quantile(L_PPET_GROWING)[4])]
# lower quartile (25% driest/warmest)
L_TEMP_JA_NEGPPET<-L_TEMP_JA[which(L_PPET_GROWING<quantile(L_PPET_GROWING)[2])]

mean(L_TEMP_JA_POSPPET)
mean(L_TEMP_JA_NEGPPET)


# U
U_TEMP_JA_single<-U_TEMP[1:113,c(8:9)]
U_TEMP_JA<-vector(mode="numeric")
for(i in 1:nrow(U_TEMP_JA_single))
{
U_TEMP_JA[i]<-
mean(as.matrix(U_TEMP_JA_single[i,]))
}

# upper quartile (25% coldest/wettest)
U_TEMP_JA_POSPPET<-U_TEMP_JA[which(U_PPET_GROWING>quantile(U_PPET_GROWING)[4])]
# lower quartile (25% driest/warmest)
U_TEMP_JA_NEGPPET<-U_TEMP_JA[which(U_PPET_GROWING<quantile(U_PPET_GROWING)[2])]

mean(U_TEMP_JA_POSPPET)
mean(U_TEMP_JA_NEGPPET)


# O
O_TEMP_JA_single<-O_TEMP[1:113,c(8:9)]
O_TEMP_JA<-vector(mode="numeric")
for(i in 1:nrow(O_TEMP_JA_single))
{
O_TEMP_JA[i]<-
mean(as.matrix(O_TEMP_JA_single[i,]))
}

# upper quartile (25% coldest/wettest)
O_TEMP_JA_POSPPET<-O_TEMP_JA[which(O_PPET_GROWING>quantile(O_PPET_GROWING)[4])]
# lower quartile (25% driest/warmest)
O_TEMP_JA_NEGPPET<-O_TEMP_JA[which(O_PPET_GROWING<quantile(O_PPET_GROWING)[2])]

mean(O_TEMP_JA_POSPPET)
mean(O_TEMP_JA_NEGPPET)


# H
H_TEMP_JA_single<-H_TEMP[1:113,c(8:9)]
H_TEMP_JA<-vector(mode="numeric")
for(i in 1:nrow(H_TEMP_JA_single))
{
H_TEMP_JA[i]<-
mean(as.matrix(H_TEMP_JA_single[i,]))
}

# upper quartile (25% coldest/wettest)
H_TEMP_JA_POSPPET<-H_TEMP_JA[which(H_PPET_GROWING>quantile(H_PPET_GROWING)[4])]
# lower quartile (25% driest/warmest)
H_TEMP_JA_NEGPPET<-H_TEMP_JA[which(H_PPET_GROWING<quantile(H_PPET_GROWING)[2])]

mean(H_TEMP_JA_POSPPET)
mean(H_TEMP_JA_NEGPPET)


# G
G_TEMP_JA_single<-G_TEMP[1:113,c(8:9)]
G_TEMP_JA<-vector(mode="numeric")
for(i in 1:nrow(G_TEMP_JA_single))
{
G_TEMP_JA[i]<-
mean(as.matrix(G_TEMP_JA_single[i,]))
}

# upper quartile (25% coldest/wettest)
G_TEMP_JA_POSPPET<-G_TEMP_JA[which(G_PPET_GROWING>quantile(G_PPET_GROWING)[4])]
# lower quartile (25% driest/warmest)
G_TEMP_JA_NEGPPET<-G_TEMP_JA[which(G_PPET_GROWING<quantile(G_PPET_GROWING)[2])]

mean(G_TEMP_JA_POSPPET)
mean(G_TEMP_JA_NEGPPET)













##################################################################################################
# (VI)	load tree-ring data per site and proxy, standardize, and synchronize IDs 

# set working directory
#setwd("")

# K

KDPS_TRW<-read.rwl("KDPS_TRW_bystem.rwl")
KWPS_TRW<-read.rwl("KWPS_TRW_bystem.rwl")

SPLINE30_KDPS_TRW<-detrend(as.data.frame(KDPS_TRW),method="Spline",nyrs=30)
SPLINE30_KWPS_TRW<-detrend(as.data.frame(KWPS_TRW),method="Spline",nyrs=30)

K1_TRW<-detrend(as.data.frame(SPLINE30_KDPS_TRW),method="Ar")
K2_TRW<-detrend(as.data.frame(SPLINE30_KWPS_TRW),method="Ar")

KDPS_MXD<-read.rwl("KDPS_MXD_bystem.rwl")
KWPS_MXD<-read.rwl("KWPS_MXD_bystem.rwl")

SPLINE30_KDPS_MXD<-detrend(as.data.frame(KDPS_MXD),method="Spline",nyrs=30)
SPLINE30_KWPS_MXD<-detrend(as.data.frame(KWPS_MXD),method="Spline",nyrs=30)

K1_MXD<-detrend(as.data.frame(SPLINE30_KDPS_MXD),method="Ar")
K2_MXD<-detrend(as.data.frame(SPLINE30_KWPS_MXD),method="Ar")

# check if IDs are the same in TRW and MXD, otherwise exclude and make new object
colnames(K1_TRW)==colnames(K1_MXD) # ok
colnames(K2_TRW)==colnames(K2_MXD) # ok



# L

LDPS_TRW<-read.rwl("LDPS_TRW_bystem.rwl")
LWPS_TRW<-read.rwl("LWPS_TRW_bystem.rwl")

SPLINE30_LDPS_TRW<-detrend(as.data.frame(LDPS_TRW),method="Spline",nyrs=30)
SPLINE30_LWPS_TRW<-detrend(as.data.frame(LWPS_TRW),method="Spline",nyrs=30)

L1_TRW<-detrend(as.data.frame(SPLINE30_LDPS_TRW),method="Ar")
L2_TRW<-detrend(as.data.frame(SPLINE30_LWPS_TRW),method="Ar")

LDPS_MXD<-read.rwl("LDPS_MXD_bystem.rwl")
LWPS_MXD<-read.rwl("LWPS_MXD_bystem.rwl")

SPLINE30_LDPS_MXD<-detrend(as.data.frame(LDPS_MXD),method="Spline",nyrs=30)
SPLINE30_LWPS_MXD<-detrend(as.data.frame(LWPS_MXD),method="Spline",nyrs=30)

L1_MXD<-detrend(as.data.frame(SPLINE30_LDPS_MXD),method="Ar")
L2_MXD<-detrend(as.data.frame(SPLINE30_LWPS_MXD),method="Ar")

# check if IDs are the same in TRW and MXD, otherwise exclude and make new object
colnames(L1_TRW)==colnames(L1_MXD) # ok
colnames(L2_TRW)==colnames(L2_MXD) # ok



# U

UDPS_TRW<-read.rwl("UDPS_TRW_bystem.rwl")
UWPS_TRW<-read.rwl("UWPS_TRW_bystem.rwl")

SPLINE30_UDPS_TRW<-detrend(UDPS_TRW,method="Spline",nyrs=30)
SPLINE30_UWPS_TRW<-detrend(UWPS_TRW,method="Spline",nyrs=30)

U1_TRW<-detrend(SPLINE30_UDPS_TRW,method="Ar")
U2_TRW<-detrend(SPLINE30_UWPS_TRW,method="Ar")

UDPS_MXD<-read.rwl("UDPS_MXD_bystem.rwl")
UWPS_MXD<-read.rwl("UWPS_MXD_bystem.rwl")

SPLINE30_UDPS_MXD<-detrend(UDPS_MXD[-274,],method="Spline",nyrs=30)
SPLINE30_UWPS_MXD<-detrend(UWPS_MXD[-284,],method="Spline",nyrs=30)

U1_MXD<-detrend(SPLINE30_UDPS_MXD,method="Ar")
U2_MXD<-detrend(SPLINE30_UWPS_MXD,method="Ar")

# check if IDs are the same in TRW and MXD, otherwise exclude and make new object
colnames(U1_TRW)==colnames(U1_MXD) # ok
colnames(U2_TRW)==colnames(U2_MXD) # ok



# O

ODPS_TRW<-read.rwl("ODPS_TRW_bystem.rwl")
OWPS_TRW<-read.rwl("OWPS_TRW_bystem.rwl")

SPLINE30_ODPS_TRW<-detrend(ODPS_TRW,method="Spline",nyrs=30)
SPLINE30_OWPS_TRW<-detrend(OWPS_TRW,method="Spline",nyrs=30)

O1_TRW<-detrend(SPLINE30_ODPS_TRW,method="Ar")
O2_TRW<-detrend(SPLINE30_OWPS_TRW,method="Ar")

ODPS_MXD<-read.rwl("ODPS_MXD_bystem.rwl")
OWPS_MXD<-read.rwl("OWPS_MXD_bystem.rwl")

SPLINE30_ODPS_MXD<-detrend(ODPS_MXD[-271,],method="Spline",nyrs=30)
SPLINE30_OWPS_MXD<-detrend(OWPS_MXD[-199,],method="Spline",nyrs=30)

O1_MXD<-detrend(SPLINE30_ODPS_MXD,method="Ar")
O2_MXD<-detrend(SPLINE30_OWPS_MXD,method="Ar")

# check if IDs are the same in TRW and MXD, otherwise exclude and make new object
colnames(O1_TRW)==colnames(O1_MXD) # ok
colnames(O2_TRW)==colnames(O2_MXD) # adjust

O2_TRW<-O2_TRW[,-c(1,4,11,15,20)] # now ok



# H

HDPS_TRW<-read.rwl("HDPS_TRW_bystem.rwl")
HWPS_TRW<-read.rwl("HWPS_TRW_bystem.rwl")

SPLINE30_HDPS_TRW<-detrend(HDPS_TRW,method="Spline",nyrs=30)
SPLINE30_HWPS_TRW<-detrend(HWPS_TRW,method="Spline",nyrs=30)

H1_TRW<-detrend(SPLINE30_HDPS_TRW,method="Ar")
H2_TRW<-detrend(SPLINE30_HWPS_TRW,method="Ar")

HDPS_MXD<-read.rwl("HDPS_MXD_bystem.rwl")
HWPS_MXD<-read.rwl("HWPS_MXD_bystem.rwl")

SPLINE30_HDPS_MXD<-detrend(HDPS_MXD,method="Spline",nyrs=30)
SPLINE30_HWPS_MXD<-detrend(HWPS_MXD,method="Spline",nyrs=30)

H1_MXD<-detrend(SPLINE30_HDPS_MXD,method="Ar")
H2_MXD<-detrend(SPLINE30_HWPS_MXD,method="Ar")

# check if IDs are the same in TRW and MXD, otherwise exclude and make new object
colnames(H1_TRW)==colnames(H1_MXD) # adjust
colnames(H2_TRW)==colnames(H2_MXD) # adjust

H1_TRW<-H1_TRW[,-16] # ok now
H2_TRW<-H2_TRW[,-c(14,19,23,28)] # ok now





# G

GDPS_TRW<-read.rwl("GDPS_TRW_bystem.rwl")
GWPS_TRW<-read.rwl("GWPS_TRW_bystem.rwl")

# exclude GWPS003
GWPS_TRW<-GWPS_TRW[,-3]

SPLINE30_GDPS_TRW<-detrend(GDPS_TRW,method="Spline",nyrs=30)
SPLINE30_GWPS_TRW<-detrend(GWPS_TRW,method="Spline",nyrs=30)

G1_TRW<-detrend(SPLINE30_GDPS_TRW,method="Ar")
G2_TRW<-detrend(SPLINE30_GWPS_TRW,method="Ar")

GDPS_MXD<-read.rwl("GDPS_MXD_bystem.rwl")
GWPS_MXD<-read.rwl("GWPS_MXD_bystem.rwl")

SPLINE30_GDPS_MXD<-detrend(GDPS_MXD,method="Spline",nyrs=30)
SPLINE30_GWPS_MXD<-detrend(GWPS_MXD,method="Spline",nyrs=30)

G1_MXD<-detrend(SPLINE30_GDPS_MXD,method="Ar")
G2_MXD<-detrend(SPLINE30_GWPS_MXD,method="Ar")

# check if IDs are the same in TRW and MXD, otherwise exclude and make new object
colnames(G1_TRW)==colnames(G1_MXD) # adjust
colnames(G2_TRW)==colnames(G2_MXD) # adjust

G1_TRW<-G1_TRW[,-29] # ok now
G2_TRW<-G2_TRW[,-14] # ok now









##################################################################################################
# (VII)	climate-growth correlations for climate regimes using site chronologies: MXD


# procedure for each micro-site (e.g. K1) and climate regime (e.g. wet/cold):
# define new MXD object that contains only data that belong to the respective climate regime (e.g. K1_MXD_POSPPET); add new continuous rownames (required for treeclim)
# define new TEMP object that contains only data that belong to the respective climate regime (e.g. K_MXD_TEMP_POSPPET); add new continuous rownames, also in 1st column (required for treeclim)
# do climate-growth correlation between tree-ring data and TEMP for the respective climate regime and define as object (e.g. corr_K1_MXD_TEMP_POSPPET)



# K1 - wet/cold

K1_MXD_POSPPET<-K1_MXD[as.character(which(K_PPET_GROWING>quantile(K_PPET_GROWING)[4])+1900),]
rownames(K1_MXD_POSPPET)<-1:nrow(K1_MXD_POSPPET)

K_MXD_TEMP_POSPPET<-K_TEMP[which(K_PPET_GROWING>quantile(K_PPET_GROWING)[4]),]
K_MXD_TEMP_POSPPET[,1]<-as.numeric(rownames(K1_MXD_POSPPET))
rownames(K_MXD_TEMP_POSPPET)<-rownames(K1_MXD_POSPPET)

corr_K1_MXD_TEMP_POSPPET <- dcc(chron(K1_MXD_POSPPET), K_MXD_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_K1_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# K1- dry/warm

K1_MXD_NEGPPET<-K1_MXD[as.character(which(K_PPET_GROWING<quantile(K_PPET_GROWING)[2])+1900),]
rownames(K1_MXD_NEGPPET)<-1:nrow(K1_MXD_NEGPPET)

K_MXD_TEMP_NEGPPET<-K_TEMP[which(K_PPET_GROWING<quantile(K_PPET_GROWING)[2]),]
K_MXD_TEMP_NEGPPET[,1]<-as.numeric(rownames(K1_MXD_NEGPPET))
rownames(K_MXD_TEMP_NEGPPET)<-rownames(K1_MXD_NEGPPET)

corr_K1_MXD_TEMP_NEGPPET <- dcc(chron(K1_MXD_NEGPPET), K_MXD_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_K1_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# K2 - wet/cold

K2_MXD_POSPPET<-K2_MXD[as.character(which(K_PPET_GROWING>quantile(K_PPET_GROWING)[4])+1900),]
rownames(K2_MXD_POSPPET)<-1:nrow(K2_MXD_POSPPET)

K_MXD_TEMP_POSPPET<-K_TEMP[which(K_PPET_GROWING>quantile(K_PPET_GROWING)[4]),]
K_MXD_TEMP_POSPPET[,1]<-as.numeric(rownames(K2_MXD_POSPPET))
rownames(K_MXD_TEMP_POSPPET)<-rownames(K2_MXD_POSPPET)

corr_K2_MXD_TEMP_POSPPET <- dcc(chron(K2_MXD_POSPPET), K_MXD_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_K2_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# K2 - dry/warm

K2_MXD_NEGPPET<-K2_MXD[as.character(which(K_PPET_GROWING<quantile(K_PPET_GROWING)[2])+1900),]
rownames(K2_MXD_NEGPPET)<-1:nrow(K2_MXD_NEGPPET)

K_MXD_TEMP_NEGPPET<-K_TEMP[which(K_PPET_GROWING<quantile(K_PPET_GROWING)[2]),]
K_MXD_TEMP_NEGPPET[,1]<-as.numeric(rownames(K2_MXD_NEGPPET))
rownames(K_MXD_TEMP_NEGPPET)<-rownames(K2_MXD_NEGPPET)

corr_K2_MXD_TEMP_NEGPPET <- dcc(chron(K2_MXD_NEGPPET), K_MXD_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_K2_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)



# L1 - wet/cold

L1_MXD_POSPPET<-L1_MXD[as.character(which(L_PPET_GROWING>quantile(L_PPET_GROWING)[4])+1900),]
rownames(L1_MXD_POSPPET)<-1:nrow(L1_MXD_POSPPET)

L_MXD_TEMP_POSPPET<-L_TEMP[which(L_PPET_GROWING>quantile(L_PPET_GROWING)[4]),]
L_MXD_TEMP_POSPPET[,1]<-as.numeric(rownames(L1_MXD_POSPPET))
rownames(L_MXD_TEMP_POSPPET)<-rownames(L1_MXD_POSPPET)

corr_L1_MXD_TEMP_POSPPET <- dcc(chron(L1_MXD_POSPPET), L_MXD_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_L1_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# L1 - dry/warm

L1_MXD_NEGPPET<-L1_MXD[as.character(which(L_PPET_GROWING<quantile(L_PPET_GROWING)[2])+1900),]
rownames(L1_MXD_NEGPPET)<-1:nrow(L1_MXD_NEGPPET)

L_MXD_TEMP_NEGPPET<-L_TEMP[which(L_PPET_GROWING<quantile(L_PPET_GROWING)[2]),]
L_MXD_TEMP_NEGPPET[,1]<-as.numeric(rownames(L1_MXD_NEGPPET))
rownames(L_MXD_TEMP_NEGPPET)<-rownames(L1_MXD_NEGPPET)

corr_L1_MXD_TEMP_NEGPPET <- dcc(chron(L1_MXD_NEGPPET), L_MXD_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_L1_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# L2 - wet/cold

L2_MXD_POSPPET<-L2_MXD[as.character(which(L_PPET_GROWING>quantile(L_PPET_GROWING)[4])+1900),]
rownames(L2_MXD_POSPPET)<-1:nrow(L2_MXD_POSPPET)

L_MXD_TEMP_POSPPET<-L_TEMP[which(L_PPET_GROWING>quantile(L_PPET_GROWING)[4]),]
L_MXD_TEMP_POSPPET[,1]<-as.numeric(rownames(L2_MXD_POSPPET))
rownames(L_MXD_TEMP_POSPPET)<-rownames(L2_MXD_POSPPET)

corr_L2_MXD_TEMP_POSPPET <- dcc(chron(L2_MXD_POSPPET), L_MXD_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_L2_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# L2 - dry/warm

L2_MXD_NEGPPET<-L2_MXD[as.character(which(L_PPET_GROWING<quantile(L_PPET_GROWING)[2])+1900),]
rownames(L2_MXD_NEGPPET)<-1:nrow(L2_MXD_NEGPPET)

L_MXD_TEMP_NEGPPET<-L_TEMP[which(L_PPET_GROWING<quantile(L_PPET_GROWING)[2]),]
L_MXD_TEMP_NEGPPET[,1]<-as.numeric(rownames(L2_MXD_NEGPPET))
rownames(L_MXD_TEMP_NEGPPET)<-rownames(L2_MXD_NEGPPET)

corr_L2_MXD_TEMP_NEGPPET <- dcc(chron(L2_MXD_NEGPPET), L_MXD_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_L2_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# U1 - wet/cold

U1_MXD_POSPPET<-U1_MXD[as.character(which(U_PPET_GROWING>quantile(U_PPET_GROWING)[4])+1900),]
rownames(U1_MXD_POSPPET)<-1:nrow(U1_MXD_POSPPET)

U_MXD_TEMP_POSPPET<-U_TEMP[which(U_PPET_GROWING>quantile(U_PPET_GROWING)[4]),]
U_MXD_TEMP_POSPPET[,1]<-as.numeric(rownames(U1_MXD_POSPPET))
rownames(U_MXD_TEMP_POSPPET)<-rownames(U1_MXD_POSPPET)

corr_U1_MXD_TEMP_POSPPET <- dcc(chron(U1_MXD_POSPPET), U_MXD_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_U1_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# U1 - dry/warm

U1_MXD_NEGPPET<-U1_MXD[as.character(which(U_PPET_GROWING<quantile(U_PPET_GROWING)[2])+1900),]
rownames(U1_MXD_NEGPPET)<-1:nrow(U1_MXD_NEGPPET)

U_MXD_TEMP_NEGPPET<-U_TEMP[which(U_PPET_GROWING<quantile(U_PPET_GROWING)[2]),]
U_MXD_TEMP_NEGPPET[,1]<-as.numeric(rownames(U1_MXD_NEGPPET))
rownames(U_MXD_TEMP_NEGPPET)<-rownames(U1_MXD_NEGPPET)

corr_U1_MXD_TEMP_NEGPPET <- dcc(chron(U1_MXD_NEGPPET), U_MXD_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_U1_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# U2 - wet/cold

U2_MXD_POSPPET<-U2_MXD[as.character(which(U_PPET_GROWING>quantile(U_PPET_GROWING)[4])+1900),]
rownames(U2_MXD_POSPPET)<-1:nrow(U2_MXD_POSPPET)

U_MXD_TEMP_POSPPET<-U_TEMP[which(U_PPET_GROWING>quantile(U_PPET_GROWING)[4]),]
U_MXD_TEMP_POSPPET[,1]<-as.numeric(rownames(U2_MXD_POSPPET))
rownames(U_MXD_TEMP_POSPPET)<-rownames(U2_MXD_POSPPET)

corr_U2_MXD_TEMP_POSPPET <- dcc(chron(U2_MXD_POSPPET), U_MXD_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_U2_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# U2 - dry/warm

U2_MXD_NEGPPET<-U2_MXD[as.character(which(U_PPET_GROWING<quantile(U_PPET_GROWING)[2])+1900),]
rownames(U2_MXD_NEGPPET)<-1:nrow(U2_MXD_NEGPPET)

U_MXD_TEMP_NEGPPET<-U_TEMP[which(U_PPET_GROWING<quantile(U_PPET_GROWING)[2]),]
U_MXD_TEMP_NEGPPET[,1]<-as.numeric(rownames(U2_MXD_NEGPPET))
rownames(U_MXD_TEMP_NEGPPET)<-rownames(U2_MXD_NEGPPET)

corr_U2_MXD_TEMP_NEGPPET <- dcc(chron(U2_MXD_NEGPPET), U_MXD_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_U2_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)



# O1 - wet/cold

O1_MXD_POSPPET<-O1_MXD[as.character(which(O_PPET_GROWING>quantile(O_PPET_GROWING)[4])+1900),]
rownames(O1_MXD_POSPPET)<-1:nrow(O1_MXD_POSPPET)

O_MXD_TEMP_POSPPET<-O_TEMP[which(O_PPET_GROWING>quantile(O_PPET_GROWING)[4]),]
O_MXD_TEMP_POSPPET[,1]<-as.numeric(rownames(O1_MXD_POSPPET))
rownames(O_MXD_TEMP_POSPPET)<-rownames(O1_MXD_POSPPET)

corr_O1_MXD_TEMP_POSPPET <- dcc(chron(O1_MXD_POSPPET), O_MXD_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_O1_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# O1 - dry/warm

O1_MXD_NEGPPET<-O1_MXD[as.character(which(O_PPET_GROWING<quantile(O_PPET_GROWING)[2])+1900),]
rownames(O1_MXD_NEGPPET)<-1:nrow(O1_MXD_NEGPPET)

O_MXD_TEMP_NEGPPET<-O_TEMP[which(O_PPET_GROWING<quantile(O_PPET_GROWING)[2]),]
O_MXD_TEMP_NEGPPET[,1]<-as.numeric(rownames(O1_MXD_NEGPPET))
rownames(O_MXD_TEMP_NEGPPET)<-rownames(O1_MXD_NEGPPET)

corr_O1_MXD_TEMP_NEGPPET <- dcc(chron(O1_MXD_NEGPPET), O_MXD_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_O1_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# O2 - wet/cold

O2_MXD_POSPPET<-O2_MXD[as.character(which(O_PPET_GROWING>quantile(O_PPET_GROWING)[4])+1900),]
rownames(O2_MXD_POSPPET)<-1:nrow(O2_MXD_POSPPET)

O_MXD_TEMP_POSPPET<-O_TEMP[which(O_PPET_GROWING>quantile(O_PPET_GROWING)[4]),]
O_MXD_TEMP_POSPPET[,1]<-as.numeric(rownames(O2_MXD_POSPPET))
rownames(O_MXD_TEMP_POSPPET)<-rownames(O2_MXD_POSPPET)

corr_O2_MXD_TEMP_POSPPET <- dcc(chron(O2_MXD_POSPPET), O_MXD_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_O2_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# O2 - dry/warm

O2_MXD_NEGPPET<-O2_MXD[as.character(which(O_PPET_GROWING<quantile(O_PPET_GROWING)[2])+1900),]
rownames(O2_MXD_NEGPPET)<-1:nrow(O2_MXD_NEGPPET)

O_MXD_TEMP_NEGPPET<-O_TEMP[which(O_PPET_GROWING<quantile(O_PPET_GROWING)[2]),]
O_MXD_TEMP_NEGPPET[,1]<-as.numeric(rownames(O2_MXD_NEGPPET))
rownames(O_MXD_TEMP_NEGPPET)<-rownames(O2_MXD_NEGPPET)

corr_O2_MXD_TEMP_NEGPPET <- dcc(chron(O2_MXD_NEGPPET), O_MXD_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_O2_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)



# H1 - wet/cold

H1_MXD_POSPPET<-H1_MXD[as.character(which(H_PPET_GROWING>quantile(H_PPET_GROWING)[4])+1900),]
rownames(H1_MXD_POSPPET)<-1:nrow(H1_MXD_POSPPET)

H_MXD_TEMP_POSPPET<-H_TEMP[which(H_PPET_GROWING>quantile(H_PPET_GROWING)[4]),]
H_MXD_TEMP_POSPPET[,1]<-as.numeric(rownames(H1_MXD_POSPPET))
rownames(H_MXD_TEMP_POSPPET)<-rownames(H1_MXD_POSPPET)

corr_H1_MXD_TEMP_POSPPET <- dcc(chron(H1_MXD_POSPPET), H_MXD_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_H1_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# H1 - dry/warm

H1_MXD_NEGPPET<-H1_MXD[as.character(which(H_PPET_GROWING<quantile(H_PPET_GROWING)[2])+1900),]
rownames(H1_MXD_NEGPPET)<-1:nrow(H1_MXD_NEGPPET)

H_MXD_TEMP_NEGPPET<-H_TEMP[which(H_PPET_GROWING<quantile(H_PPET_GROWING)[2]),]
H_MXD_TEMP_NEGPPET[,1]<-as.numeric(rownames(H1_MXD_NEGPPET))
rownames(H_MXD_TEMP_NEGPPET)<-rownames(H1_MXD_NEGPPET)

corr_H1_MXD_TEMP_NEGPPET <- dcc(chron(H1_MXD_NEGPPET), H_MXD_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_H1_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# H2 - wet/cold

H2_MXD_POSPPET<-H2_MXD[as.character(which(H_PPET_GROWING>quantile(H_PPET_GROWING)[4])+1900),]
rownames(H2_MXD_POSPPET)<-1:nrow(H2_MXD_POSPPET)

H_MXD_TEMP_POSPPET<-H_TEMP[which(H_PPET_GROWING>quantile(H_PPET_GROWING)[4]),]
H_MXD_TEMP_POSPPET[,1]<-as.numeric(rownames(H2_MXD_POSPPET))
rownames(H_MXD_TEMP_POSPPET)<-rownames(H2_MXD_POSPPET)

corr_H2_MXD_TEMP_POSPPET <- dcc(chron(H2_MXD_POSPPET), H_MXD_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_H2_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# H2 - dry/warm

H2_MXD_NEGPPET<-H2_MXD[as.character(which(H_PPET_GROWING<quantile(H_PPET_GROWING)[2])+1900),]
rownames(H2_MXD_NEGPPET)<-1:nrow(H2_MXD_NEGPPET)

H_MXD_TEMP_NEGPPET<-H_TEMP[which(H_PPET_GROWING<quantile(H_PPET_GROWING)[2]),]
H_MXD_TEMP_NEGPPET[,1]<-as.numeric(rownames(H2_MXD_NEGPPET))
rownames(H_MXD_TEMP_NEGPPET)<-rownames(H2_MXD_NEGPPET)

corr_H2_MXD_TEMP_NEGPPET <- dcc(chron(H2_MXD_NEGPPET), H_MXD_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_H2_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


 
# G1 - wet/cold

G1_MXD_POSPPET<-G1_MXD[as.character(which(G_PPET_GROWING>quantile(G_PPET_GROWING)[4])+1900),]
rownames(G1_MXD_POSPPET)<-1:nrow(G1_MXD_POSPPET)

G_MXD_TEMP_POSPPET<-G_TEMP[which(G_PPET_GROWING>quantile(G_PPET_GROWING)[4]),]
G_MXD_TEMP_POSPPET[,1]<-as.numeric(rownames(G1_MXD_POSPPET))
rownames(G_MXD_TEMP_POSPPET)<-rownames(G1_MXD_POSPPET)

corr_G1_MXD_TEMP_POSPPET <- dcc(chron(G1_MXD_POSPPET), G_MXD_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_G1_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# G1 - dry/warm

G1_MXD_NEGPPET<-G1_MXD[as.character(which(G_PPET_GROWING<quantile(G_PPET_GROWING)[2])+1900),]
rownames(G1_MXD_NEGPPET)<-1:nrow(G1_MXD_NEGPPET)

G_MXD_TEMP_NEGPPET<-G_TEMP[which(G_PPET_GROWING<quantile(G_PPET_GROWING)[2]),]
G_MXD_TEMP_NEGPPET[,1]<-as.numeric(rownames(G1_MXD_NEGPPET))
rownames(G_MXD_TEMP_NEGPPET)<-rownames(G1_MXD_NEGPPET)

corr_G1_MXD_TEMP_NEGPPET <- dcc(chron(G1_MXD_NEGPPET), G_MXD_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_G1_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# G2 - wet/cold

G2_MXD_POSPPET<-G2_MXD[as.character(which(G_PPET_GROWING>quantile(G_PPET_GROWING)[4])+1900),]
rownames(G2_MXD_POSPPET)<-1:nrow(G2_MXD_POSPPET)

G_MXD_TEMP_POSPPET<-G_TEMP[which(G_PPET_GROWING>quantile(G_PPET_GROWING)[4]),]
G_MXD_TEMP_POSPPET[,1]<-as.numeric(rownames(G2_MXD_POSPPET))
rownames(G_MXD_TEMP_POSPPET)<-rownames(G2_MXD_POSPPET)

corr_G2_MXD_TEMP_POSPPET <- dcc(chron(G2_MXD_POSPPET), G_MXD_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_G2_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# G2 - dry/warm

G2_MXD_NEGPPET<-G2_MXD[as.character(which(G_PPET_GROWING<quantile(G_PPET_GROWING)[2])+1900),]
rownames(G2_MXD_NEGPPET)<-1:nrow(G2_MXD_NEGPPET)

G_MXD_TEMP_NEGPPET<-G_TEMP[which(G_PPET_GROWING<quantile(G_PPET_GROWING)[2]),]
G_MXD_TEMP_NEGPPET[,1]<-as.numeric(rownames(G2_MXD_NEGPPET))
rownames(G_MXD_TEMP_NEGPPET)<-rownames(G2_MXD_NEGPPET)

corr_G2_MXD_TEMP_NEGPPET <- dcc(chron(G2_MXD_NEGPPET), G_MXD_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_G2_MXD~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)








##################################################################################################
# (VIII)	climate-growth correlations for climate regimes using individual trees: MXD~T_JA


CORR_K1_MXD_POSPPET <- as.data.frame(t(cor(K_TEMP_JA_POSPPET,
                           K1_MXD_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_K1_MXD_NEGPPET <- as.data.frame(t(cor(K_TEMP_JA_NEGPPET,
                           K1_MXD_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_K2_MXD_POSPPET <- as.data.frame(t(cor(K_TEMP_JA_POSPPET,
                            K2_MXD_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_K2_MXD_NEGPPET <- as.data.frame(t(cor(K_TEMP_JA_NEGPPET,
                            K2_MXD_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_L1_MXD_POSPPET <- as.data.frame(t(cor(L_TEMP_JA_POSPPET,
                            L1_MXD_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_L1_MXD_NEGPPET <- as.data.frame(t(cor(L_TEMP_JA_NEGPPET,
                            L1_MXD_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_L2_MXD_POSPPET <- as.data.frame(t(cor(L_TEMP_JA_POSPPET,
                            L2_MXD_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_L2_MXD_NEGPPET <- as.data.frame(t(cor(L_TEMP_JA_NEGPPET,
                            L2_MXD_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_U1_MXD_POSPPET <- as.data.frame(t(cor(U_TEMP_JA_POSPPET,
                            U1_MXD_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_U1_MXD_NEGPPET <- as.data.frame(t(cor(U_TEMP_JA_NEGPPET,
                            U1_MXD_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_U2_MXD_POSPPET <- as.data.frame(t(cor(U_TEMP_JA_POSPPET,
                            U2_MXD_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_U2_MXD_NEGPPET <- as.data.frame(t(cor(U_TEMP_JA_NEGPPET,
                            U2_MXD_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_O1_MXD_POSPPET <- as.data.frame(t(cor(O_TEMP_JA_POSPPET,
                            O1_MXD_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_O1_MXD_NEGPPET <- as.data.frame(t(cor(O_TEMP_JA_NEGPPET,
                            O1_MXD_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_O2_MXD_POSPPET <- as.data.frame(t(cor(O_TEMP_JA_POSPPET,
                            O2_MXD_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_O2_MXD_NEGPPET <- as.data.frame(t(cor(O_TEMP_JA_NEGPPET,
                            O2_MXD_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_H1_MXD_POSPPET <- as.data.frame(t(cor(H_TEMP_JA_POSPPET,
                            H1_MXD_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_H1_MXD_NEGPPET <- as.data.frame(t(cor(H_TEMP_JA_NEGPPET,
                            H1_MXD_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_H2_MXD_POSPPET <- as.data.frame(t(cor(H_TEMP_JA_POSPPET,
                            H2_MXD_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_H2_MXD_NEGPPET <- as.data.frame(t(cor(H_TEMP_JA_NEGPPET,
                            H2_MXD_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_G1_MXD_POSPPET <- as.data.frame(t(cor(G_TEMP_JA_POSPPET,
                            G1_MXD_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_G1_MXD_NEGPPET <- as.data.frame(t(cor(G_TEMP_JA_NEGPPET,
                            G1_MXD_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_G2_MXD_POSPPET <- as.data.frame(t(cor(G_TEMP_JA_POSPPET,
                            G2_MXD_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_G2_MXD_NEGPPET <- as.data.frame(t(cor(G_TEMP_JA_NEGPPET,
                            G2_MXD_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))








##################################################################################################
# (IX)	climate-growth correlations for climate regimes using site chronologies: TRW


# procedure for each micro-site (e.g. K1) and climate regime (e.g. wet/cold):
# define new TRW object that contains only data that belong to the respective climate regime (e.g. K1_TRW_POSPPET); add new continuous rownames (required for treeclim)
# define new TEMP object that contains only data that belong to the respective climate regime (e.g. K_TRW_TEMP_POSPPET); add new continuous rownames, also in 1st column (required for treeclim)
# do climate-growth correlation between tree-ring data and TEMP for the respective climate regime and define as object (e.g. corr_K1_TRW_TEMP_POSPPET)


# K1 - wet/cold

K1_TRW_POSPPET<-K1_TRW[as.character(which(K_PPET_GROWING>quantile(K_PPET_GROWING)[4])+1900),]
rownames(K1_TRW_POSPPET)<-1:nrow(K1_TRW_POSPPET)

K_TEMP_POSPPET<-K_TEMP[which(K_PPET_GROWING>quantile(K_PPET_GROWING)[4]),]
K_TEMP_POSPPET[,1]<-as.numeric(rownames(K1_TRW_POSPPET))
rownames(K_TEMP_POSPPET)<-rownames(K1_TRW_POSPPET)

corr_K1_TRW_TEMP_POSPPET <- dcc(chron(K1_TRW_POSPPET), K_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_K1_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# K1 - dry/warm

K1_TRW_NEGPPET<-K1_TRW[as.character(which(K_PPET_GROWING<quantile(K_PPET_GROWING)[2])+1900),]
rownames(K1_TRW_NEGPPET)<-1:nrow(K1_TRW_NEGPPET)

K_TEMP_NEGPPET<-K_TEMP[which(K_PPET_GROWING<quantile(K_PPET_GROWING)[2]),]
K_TEMP_NEGPPET[,1]<-as.numeric(rownames(K1_TRW_NEGPPET))
rownames(K_TEMP_NEGPPET)<-rownames(K1_TRW_NEGPPET)

corr_K1_TRW_TEMP_NEGPPET <- dcc(chron(K1_TRW_NEGPPET), K_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_K1_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# K2 - wet/cold

K2_TRW_POSPPET<-K2_TRW[as.character(which(K_PPET_GROWING>quantile(K_PPET_GROWING)[4])+1900),]
rownames(K2_TRW_POSPPET)<-1:nrow(K2_TRW_POSPPET)

K_TEMP_POSPPET<-K_TEMP[which(K_PPET_GROWING>quantile(K_PPET_GROWING)[4]),]
K_TEMP_POSPPET[,1]<-as.numeric(rownames(K2_TRW_POSPPET))
rownames(K_TEMP_POSPPET)<-rownames(K2_TRW_POSPPET)

corr_K2_TRW_TEMP_POSPPET <- dcc(chron(K2_TRW_POSPPET), K_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_K2_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# K2 - dry/warm

K2_TRW_NEGPPET<-K2_TRW[as.character(which(K_PPET_GROWING<quantile(K_PPET_GROWING)[2])+1900),]
rownames(K2_TRW_NEGPPET)<-1:nrow(K2_TRW_NEGPPET)

K_TEMP_NEGPPET<-K_TEMP[which(K_PPET_GROWING<quantile(K_PPET_GROWING)[2]),]
K_TEMP_NEGPPET[,1]<-as.numeric(rownames(K2_TRW_NEGPPET))
rownames(K_TEMP_NEGPPET)<-rownames(K2_TRW_NEGPPET)


corr_K2_TRW_TEMP_NEGPPET <- dcc(chron(K2_TRW_NEGPPET), K_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_K2_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)



# L1 - wet/cold

L1_TRW_POSPPET<-L1_TRW[as.character(which(L_PPET_GROWING>quantile(L_PPET_GROWING)[4])+1900),]
rownames(L1_TRW_POSPPET)<-1:nrow(L1_TRW_POSPPET)

L_TEMP_POSPPET<-L_TEMP[which(L_PPET_GROWING>quantile(L_PPET_GROWING)[4]),]
L_TEMP_POSPPET[,1]<-as.numeric(rownames(L1_TRW_POSPPET))
rownames(L_TEMP_POSPPET)<-rownames(L1_TRW_POSPPET)

corr_L1_TRW_TEMP_POSPPET <- dcc(chron(L1_TRW_POSPPET), L_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_L1_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# L1 - dry/warm

L1_TRW_NEGPPET<-L1_TRW[as.character(which(L_PPET_GROWING<quantile(L_PPET_GROWING)[2])+1900),]
rownames(L1_TRW_NEGPPET)<-1:nrow(L1_TRW_NEGPPET)

L_TEMP_NEGPPET<-L_TEMP[which(L_PPET_GROWING<quantile(L_PPET_GROWING)[2]),]
L_TEMP_NEGPPET[,1]<-as.numeric(rownames(L1_TRW_NEGPPET))
rownames(L_TEMP_NEGPPET)<-rownames(L1_TRW_NEGPPET)

corr_L1_TRW_TEMP_NEGPPET <- dcc(chron(L1_TRW_NEGPPET), L_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_L1_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# L2 - wet/cold

L2_TRW_POSPPET<-L2_TRW[as.character(which(L_PPET_GROWING>quantile(L_PPET_GROWING)[4])+1900),]
rownames(L2_TRW_POSPPET)<-1:nrow(L2_TRW_POSPPET)

L_TEMP_POSPPET<-L_TEMP[which(L_PPET_GROWING>quantile(L_PPET_GROWING)[4]),]
L_TEMP_POSPPET[,1]<-as.numeric(rownames(L2_TRW_POSPPET))
rownames(L_TEMP_POSPPET)<-rownames(L2_TRW_POSPPET)

corr_L2_TRW_TEMP_POSPPET <- dcc(chron(L2_TRW_POSPPET), L_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_L2_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# L2 - dry/warm

L2_TRW_NEGPPET<-L2_TRW[as.character(which(L_PPET_GROWING<quantile(L_PPET_GROWING)[2])+1900),]
rownames(L2_TRW_NEGPPET)<-1:nrow(L2_TRW_NEGPPET)

L_TEMP_NEGPPET<-L_TEMP[which(L_PPET_GROWING<quantile(L_PPET_GROWING)[2]),]
L_TEMP_NEGPPET[,1]<-as.numeric(rownames(L2_TRW_NEGPPET))
rownames(L_TEMP_NEGPPET)<-rownames(L2_TRW_NEGPPET)

corr_L2_TRW_TEMP_NEGPPET <- dcc(chron(L2_TRW_NEGPPET), L_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_L2_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)



# U1 - wet/cold

U1_TRW_POSPPET<-U1_TRW[as.character(which(U_PPET_GROWING>quantile(U_PPET_GROWING)[4])+1900),]
rownames(U1_TRW_POSPPET)<-1:nrow(U1_TRW_POSPPET)

U_TEMP_POSPPET<-U_TEMP[which(U_PPET_GROWING>quantile(U_PPET_GROWING)[4]),]
U_TEMP_POSPPET[,1]<-as.numeric(rownames(U1_TRW_POSPPET))
rownames(U_TEMP_POSPPET)<-rownames(U1_TRW_POSPPET)

corr_U1_TRW_TEMP_POSPPET <- dcc(chron(U1_TRW_POSPPET), U_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_U1_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# U1 - dry/warm

U1_TRW_NEGPPET<-U1_TRW[as.character(which(U_PPET_GROWING<quantile(U_PPET_GROWING)[2])+1900),]
rownames(U1_TRW_NEGPPET)<-1:nrow(U1_TRW_NEGPPET)

U_TEMP_NEGPPET<-U_TEMP[which(U_PPET_GROWING<quantile(U_PPET_GROWING)[2]),]
U_TEMP_NEGPPET[,1]<-as.numeric(rownames(U1_TRW_NEGPPET))
rownames(U_TEMP_NEGPPET)<-rownames(U1_TRW_NEGPPET)

corr_U1_TRW_TEMP_NEGPPET <- dcc(chron(U1_TRW_NEGPPET), U_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_U1_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# U2 - wet/cold

U2_TRW_POSPPET<-U2_TRW[as.character(which(U_PPET_GROWING>quantile(U_PPET_GROWING)[4])+1900),]
rownames(U2_TRW_POSPPET)<-1:nrow(U2_TRW_POSPPET)

U_TEMP_POSPPET<-U_TEMP[which(U_PPET_GROWING>quantile(U_PPET_GROWING)[4]),]
U_TEMP_POSPPET[,1]<-as.numeric(rownames(U2_TRW_POSPPET))
rownames(U_TEMP_POSPPET)<-rownames(U2_TRW_POSPPET)

corr_U2_TRW_TEMP_POSPPET <- dcc(chron(U2_TRW_POSPPET), U_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_U2_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# U2 - dry/warm

U2_TRW_NEGPPET<-U2_TRW[as.character(which(U_PPET_GROWING<quantile(U_PPET_GROWING)[2])+1900),]
rownames(U2_TRW_NEGPPET)<-1:nrow(U2_TRW_NEGPPET)

U_TEMP_NEGPPET<-U_TEMP[which(U_PPET_GROWING<quantile(U_PPET_GROWING)[2]),]
U_TEMP_NEGPPET[,1]<-as.numeric(rownames(U2_TRW_NEGPPET))
rownames(U_TEMP_NEGPPET)<-rownames(U2_TRW_NEGPPET)

corr_U2_TRW_TEMP_NEGPPET <- dcc(chron(U2_TRW_NEGPPET), U_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_U2_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)



# O1 - wet/cold

O1_TRW_POSPPET<-O1_TRW[as.character(which(O_PPET_GROWING>quantile(O_PPET_GROWING)[4])+1900),]
rownames(O1_TRW_POSPPET)<-1:nrow(O1_TRW_POSPPET)

O_TEMP_POSPPET<-O_TEMP[which(O_PPET_GROWING>quantile(O_PPET_GROWING)[4]),]
O_TEMP_POSPPET[,1]<-as.numeric(rownames(O1_TRW_POSPPET))
rownames(O_TEMP_POSPPET)<-rownames(O1_TRW_POSPPET)

corr_O1_TRW_TEMP_POSPPET <- dcc(chron(O1_TRW_POSPPET), O_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_O1_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# O1 - dry/warm

O1_TRW_NEGPPET<-O1_TRW[as.character(which(O_PPET_GROWING<quantile(O_PPET_GROWING)[2])+1900),]
rownames(O1_TRW_NEGPPET)<-1:nrow(O1_TRW_NEGPPET)

O_TEMP_NEGPPET<-O_TEMP[which(O_PPET_GROWING<quantile(O_PPET_GROWING)[2]),]
O_TEMP_NEGPPET[,1]<-as.numeric(rownames(O1_TRW_NEGPPET))
rownames(O_TEMP_NEGPPET)<-rownames(O1_TRW_NEGPPET)

corr_O1_TRW_TEMP_NEGPPET <- dcc(chron(O1_TRW_NEGPPET), O_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_O1_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# O2 - wet/cold

O2_TRW_POSPPET<-O2_TRW[as.character(which(O_PPET_GROWING>quantile(O_PPET_GROWING)[4])+1900),]
rownames(O2_TRW_POSPPET)<-1:nrow(O2_TRW_POSPPET)

O_TEMP_POSPPET<-O_TEMP[which(O_PPET_GROWING>quantile(O_PPET_GROWING)[4]),]
O_TEMP_POSPPET[,1]<-as.numeric(rownames(O2_TRW_POSPPET))
rownames(O_TEMP_POSPPET)<-rownames(O2_TRW_POSPPET)

corr_O2_TRW_TEMP_POSPPET <- dcc(chron(O2_TRW_POSPPET), O_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_O2_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# O2 - dry/warm

O2_TRW_NEGPPET<-O2_TRW[as.character(which(O_PPET_GROWING<quantile(O_PPET_GROWING)[2])+1900),]
rownames(O2_TRW_NEGPPET)<-1:nrow(O2_TRW_NEGPPET)

O_TEMP_NEGPPET<-O_TEMP[which(O_PPET_GROWING<quantile(O_PPET_GROWING)[2]),]
O_TEMP_NEGPPET[,1]<-as.numeric(rownames(O2_TRW_NEGPPET))
rownames(O_TEMP_NEGPPET)<-rownames(O2_TRW_NEGPPET)

corr_O2_TRW_TEMP_NEGPPET <- dcc(chron(O2_TRW_NEGPPET), O_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_O2_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)



# H1 - wet/cold

H1_TRW_POSPPET<-H1_TRW[as.character(which(H_PPET_GROWING>quantile(H_PPET_GROWING)[4])+1900),]
rownames(H1_TRW_POSPPET)<-1:nrow(H1_TRW_POSPPET)

H_TEMP_POSPPET<-H_TEMP[which(H_PPET_GROWING>quantile(H_PPET_GROWING)[4]),]
H_TEMP_POSPPET[,1]<-as.numeric(rownames(H1_TRW_POSPPET))
rownames(H_TEMP_POSPPET)<-rownames(H1_TRW_POSPPET)

corr_H1_TRW_TEMP_POSPPET <- dcc(chron(H1_TRW_POSPPET), H_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_H1_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# H1 - dry/warm

H1_TRW_NEGPPET<-H1_TRW[as.character(which(H_PPET_GROWING<quantile(H_PPET_GROWING)[2])+1900),]
rownames(H1_TRW_NEGPPET)<-1:nrow(H1_TRW_NEGPPET)

H_TEMP_NEGPPET<-H_TEMP[which(H_PPET_GROWING<quantile(H_PPET_GROWING)[2]),]
H_TEMP_NEGPPET[,1]<-as.numeric(rownames(H1_TRW_NEGPPET))
rownames(H_TEMP_NEGPPET)<-rownames(H1_TRW_NEGPPET)

corr_H1_TRW_TEMP_NEGPPET <- dcc(chron(H1_TRW_NEGPPET), H_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_H1_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# H2 - wet/cold

H2_TRW_POSPPET<-H2_TRW[as.character(which(H_PPET_GROWING>quantile(H_PPET_GROWING)[4])+1900),]
rownames(H2_TRW_POSPPET)<-1:nrow(H2_TRW_POSPPET)

H_TEMP_POSPPET<-H_TEMP[which(H_PPET_GROWING>quantile(H_PPET_GROWING)[4]),]
H_TEMP_POSPPET[,1]<-as.numeric(rownames(H2_TRW_POSPPET))
rownames(H_TEMP_POSPPET)<-rownames(H2_TRW_POSPPET)

corr_H2_TRW_TEMP_POSPPET <- dcc(chron(H2_TRW_POSPPET), H_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_H2_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# H2 - dry/warm

H2_TRW_NEGPPET<-H2_TRW[as.character(which(H_PPET_GROWING<quantile(H_PPET_GROWING)[2])+1900),]
rownames(H2_TRW_NEGPPET)<-1:nrow(H2_TRW_NEGPPET)

H_TEMP_NEGPPET<-H_TEMP[which(H_PPET_GROWING<quantile(H_PPET_GROWING)[2]),]
H_TEMP_NEGPPET[,1]<-as.numeric(rownames(H2_TRW_NEGPPET))
rownames(H_TEMP_NEGPPET)<-rownames(H2_TRW_NEGPPET)

corr_H2_TRW_TEMP_NEGPPET <- dcc(chron(H2_TRW_NEGPPET), H_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_H2_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)



# G1 - wet/cold

G1_TRW_POSPPET<-G1_TRW[as.character(which(G_PPET_GROWING>quantile(G_PPET_GROWING)[4])+1900),]
rownames(G1_TRW_POSPPET)<-1:nrow(G1_TRW_POSPPET)

G_TEMP_POSPPET<-G_TEMP[which(G_PPET_GROWING>quantile(G_PPET_GROWING)[4]),]
G_TEMP_POSPPET[,1]<-as.numeric(rownames(G1_TRW_POSPPET))
rownames(G_TEMP_POSPPET)<-rownames(G1_TRW_POSPPET)

corr_G1_TRW_TEMP_POSPPET <- dcc(chron(G1_TRW_POSPPET), G_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_G1_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# G1 - dry/warm

G1_TRW_NEGPPET<-G1_TRW[as.character(which(G_PPET_GROWING<quantile(G_PPET_GROWING)[2])+1900),]
rownames(G1_TRW_NEGPPET)<-1:nrow(G1_TRW_NEGPPET)

G_TEMP_NEGPPET<-G_TEMP[which(G_PPET_GROWING<quantile(G_PPET_GROWING)[2]),]
G_TEMP_NEGPPET[,1]<-as.numeric(rownames(G1_TRW_NEGPPET))
rownames(G_TEMP_NEGPPET)<-rownames(G1_TRW_NEGPPET)

corr_G1_TRW_TEMP_NEGPPET <- dcc(chron(G1_TRW_NEGPPET), G_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_G1_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# G2 - wet/cold

G2_TRW_POSPPET<-G2_TRW[as.character(which(G_PPET_GROWING>quantile(G_PPET_GROWING)[4])+1900),]
rownames(G2_TRW_POSPPET)<-1:nrow(G2_TRW_POSPPET)

G_TEMP_POSPPET<-G_TEMP[which(G_PPET_GROWING>quantile(G_PPET_GROWING)[4]),]
G_TEMP_POSPPET[,1]<-as.numeric(rownames(G2_TRW_POSPPET))
rownames(G_TEMP_POSPPET)<-rownames(G2_TRW_POSPPET)

corr_G2_TRW_TEMP_POSPPET <- dcc(chron(G2_TRW_POSPPET), G_TEMP_POSPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_G2_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)


# G2 - dry/warm

G2_TRW_NEGPPET<-G2_TRW[as.character(which(G_PPET_GROWING<quantile(G_PPET_GROWING)[2])+1900),]
rownames(G2_TRW_NEGPPET)<-1:nrow(G2_TRW_NEGPPET)

G_TEMP_NEGPPET<-G_TEMP[which(G_PPET_GROWING<quantile(G_PPET_GROWING)[2]),]
G_TEMP_NEGPPET[,1]<-as.numeric(rownames(G2_TRW_NEGPPET))
rownames(G_TEMP_NEGPPET)<-rownames(G2_TRW_NEGPPET)

corr_G2_TRW_TEMP_NEGPPET <- dcc(chron(G2_TRW_NEGPPET), G_TEMP_NEGPPET, .range(-6:9)+.mean(7:8)+.mean(6:8)+.mean(6:7), method = "correlation",
             dynamic = "static", win_size = 40, win_offset = 1, start_last = TRUE,
             timespan = NULL, var_names = "SPLINE_G2_TRW~CRUTEMP", ci = 0.05, boot = "stationary",
             sb = TRUE)








##################################################################################################
# (X)	climate-growth correlations for climate regimes using individual trees: TRW~Temp of year of growth (corr. of T_Jul will be extracted while plotting)


CORR_K1_TRW_POSPPET <- as.data.frame(t(cor(K_TEMP_POSPPET[,2:10],
                           K1_TRW_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_K1_TRW_NEGPPET <- as.data.frame(t(cor(K_TEMP_NEGPPET[,2:10],
                           K1_TRW_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_K2_TRW_POSPPET <- as.data.frame(t(cor(K_TEMP_POSPPET[,2:10],
                            K2_TRW_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_K2_TRW_NEGPPET <- as.data.frame(t(cor(K_TEMP_NEGPPET[,2:10],
                            K2_TRW_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_L1_TRW_POSPPET <- as.data.frame(t(cor(L_TEMP_POSPPET[,2:10],
                            L1_TRW_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_L1_TRW_NEGPPET <- as.data.frame(t(cor(L_TEMP_NEGPPET[,2:10],
                            L1_TRW_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_L2_TRW_POSPPET <- as.data.frame(t(cor(L_TEMP_POSPPET[,2:10],
                            L2_TRW_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_L2_TRW_NEGPPET <- as.data.frame(t(cor(L_TEMP_NEGPPET[,2:10],
                            L2_TRW_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_U1_TRW_POSPPET <- as.data.frame(t(cor(U_TEMP_POSPPET[,2:10],
                            U1_TRW_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_U1_TRW_NEGPPET <- as.data.frame(t(cor(U_TEMP_NEGPPET[,2:10],
                            U1_TRW_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_U2_TRW_POSPPET <- as.data.frame(t(cor(U_TEMP_POSPPET[,2:10],
                            U2_TRW_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_U2_TRW_NEGPPET <- as.data.frame(t(cor(U_TEMP_NEGPPET[,2:10],
                            U2_TRW_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_O1_TRW_POSPPET <- as.data.frame(t(cor(O_TEMP_POSPPET[,2:10],
                            O1_TRW_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_O1_TRW_NEGPPET <- as.data.frame(t(cor(O_TEMP_NEGPPET[,2:10],
                            O1_TRW_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_O2_TRW_POSPPET <- as.data.frame(t(cor(O_TEMP_POSPPET[,2:10],
                            O2_TRW_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_O2_TRW_NEGPPET <- as.data.frame(t(cor(O_TEMP_NEGPPET[,2:10],
                            O2_TRW_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_H1_TRW_POSPPET <- as.data.frame(t(cor(H_TEMP_POSPPET[,2:10],
                            H1_TRW_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_H1_TRW_NEGPPET <- as.data.frame(t(cor(H_TEMP_NEGPPET[,2:10],
                            H1_TRW_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_H2_TRW_POSPPET <- as.data.frame(t(cor(H_TEMP_POSPPET[,2:10],
                            H2_TRW_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_H2_TRW_NEGPPET <- as.data.frame(t(cor(H_TEMP_NEGPPET[,2:10],
                            H2_TRW_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_G1_TRW_POSPPET <- as.data.frame(t(cor(G_TEMP_POSPPET[,2:10],
                            G1_TRW_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_G1_TRW_NEGPPET <- as.data.frame(t(cor(G_TEMP_NEGPPET[,2:10],
                            G1_TRW_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_G2_TRW_POSPPET <- as.data.frame(t(cor(G_TEMP_POSPPET[,2:10],
                            G2_TRW_POSPPET,
                            method = "pearson", use = "pairwise.complete.obs")))


CORR_G2_TRW_NEGPPET <- as.data.frame(t(cor(G_TEMP_NEGPPET[,2:10],
                            G2_TRW_NEGPPET,
                            method = "pearson", use = "pairwise.complete.obs")))








##################################################################################################
# (XI)	Wilcoxon rank-sum test for significant difference


# MXD
anovadata_FIN_MXD<-as.matrix(c(
CORR_K1_MXD_POSPPET[,1],CORR_K2_MXD_POSPPET[,1],CORR_L1_MXD_POSPPET[,1],CORR_L2_MXD_POSPPET[,1],
CORR_K1_MXD_NEGPPET[,1],CORR_K2_MXD_NEGPPET[,1],CORR_L1_MXD_NEGPPET[,1],CORR_L2_MXD_NEGPPET[,1]))

anovadata_RUS1_MXD<-as.matrix(c(
CORR_U1_MXD_POSPPET[,1],CORR_U2_MXD_POSPPET[,1],CORR_O1_MXD_POSPPET[,1],CORR_O2_MXD_POSPPET[,1],
CORR_U1_MXD_NEGPPET[,1],CORR_U2_MXD_NEGPPET[,1],CORR_O1_MXD_NEGPPET[,1],CORR_O2_MXD_NEGPPET[,1]))

anovadata_RUS2_MXD<-as.matrix(c(
CORR_H1_MXD_POSPPET[,1],CORR_H2_MXD_POSPPET[,1],CORR_G1_MXD_POSPPET[,1],CORR_G2_MXD_POSPPET[,1],
CORR_H1_MXD_NEGPPET[,1],CORR_H2_MXD_NEGPPET[,1],CORR_G1_MXD_NEGPPET[,1],CORR_G2_MXD_NEGPPET[,1]))

ids_FIN_MXD<-as.matrix(c(
rep("K1 POS",length(CORR_K1_MXD_POSPPET[,1])),rep("K2 POS",length(CORR_K2_MXD_POSPPET[,1])),
rep("L1 POS",length(CORR_L1_MXD_POSPPET[,1])),rep("L2 POS",length(CORR_L2_MXD_POSPPET[,1])),
rep("K1 NEG",length(CORR_K1_MXD_NEGPPET[,1])),rep("K2 NEG",length(CORR_K2_MXD_NEGPPET[,1])),
rep("L1 NEG",length(CORR_L1_MXD_NEGPPET[,1])),rep("L2 NEG",length(CORR_L2_MXD_NEGPPET[,1]))))

ids_RUS1_MXD<-as.matrix(c(
rep("U1 POS",length(CORR_U1_MXD_POSPPET[,1])),rep("U2 POS",length(CORR_U2_MXD_POSPPET[,1])),
rep("O1 POS",length(CORR_O1_MXD_POSPPET[,1])),rep("O2 POS",length(CORR_O2_MXD_POSPPET[,1])),
rep("U1 NEG",length(CORR_U1_MXD_NEGPPET[,1])),rep("U2 NEG",length(CORR_U2_MXD_NEGPPET[,1])),
rep("O1 NEG",length(CORR_O1_MXD_NEGPPET[,1])),rep("O2 NEG",length(CORR_O2_MXD_NEGPPET[,1]))))

ids_RUS2_MXD<-as.matrix(c(
rep("H1 POS",length(CORR_H1_MXD_POSPPET[,1])),rep("H2 POS",length(CORR_H2_MXD_POSPPET[,1])),
rep("G1 POS",length(CORR_G1_MXD_POSPPET[,1])),rep("G2 POS",length(CORR_G2_MXD_POSPPET[,1])),
rep("H1 NEG",length(CORR_H1_MXD_NEGPPET[,1])),rep("H2 NEG",length(CORR_H2_MXD_NEGPPET[,1])),
rep("G1 NEG",length(CORR_G1_MXD_NEGPPET[,1])),rep("G2 NEG",length(CORR_G2_MXD_NEGPPET[,1]))))

out_WILCOX_FIN_MXD<-pairwise.wilcox.test(anovadata_FIN_MXD,as.factor(ids_FIN_MXD),method="holm")
out_WILCOX_RUS1_MXD<-pairwise.wilcox.test(anovadata_RUS1_MXD,as.factor(ids_RUS1_MXD),method="holm")
out_WILCOX_RUS2_MXD<-pairwise.wilcox.test(anovadata_RUS2_MXD,as.factor(ids_RUS2_MXD),method="holm")





# TRW
anovadata_FIN_TRW<-as.matrix(c(
CORR_K1_TRW_POSPPET[,7],CORR_K2_TRW_POSPPET[,7],CORR_L1_TRW_POSPPET[,7],CORR_L2_TRW_POSPPET[,7],
CORR_K1_TRW_NEGPPET[,7],CORR_K2_TRW_NEGPPET[,7],CORR_L1_TRW_NEGPPET[,7],CORR_L2_TRW_NEGPPET[,7]))

anovadata_RUS1_TRW<-as.matrix(c(
CORR_U1_TRW_POSPPET[,7],CORR_U2_TRW_POSPPET[,7],CORR_O1_TRW_POSPPET[,7],CORR_O2_TRW_POSPPET[,7],
CORR_U1_TRW_NEGPPET[,7],CORR_U2_TRW_NEGPPET[,7],CORR_O1_TRW_NEGPPET[,7],CORR_O2_TRW_NEGPPET[,7]))

anovadata_RUS2_TRW<-as.matrix(c(
CORR_H1_TRW_POSPPET[,7],CORR_H2_TRW_POSPPET[,7],CORR_G1_TRW_POSPPET[,7],CORR_G2_TRW_POSPPET[,7],
CORR_H1_TRW_NEGPPET[,7],CORR_H2_TRW_NEGPPET[,7],CORR_G1_TRW_NEGPPET[,7],CORR_G2_TRW_NEGPPET[,7]))

ids_FIN_TRW<-as.matrix(c(
rep("K1 POS",length(CORR_K1_TRW_POSPPET[,7])),rep("K2 POS",length(CORR_K2_TRW_POSPPET[,7])),
rep("L1 POS",length(CORR_L1_TRW_POSPPET[,7])),rep("L2 POS",length(CORR_L2_TRW_POSPPET[,7])),
rep("K1 NEG",length(CORR_K1_TRW_NEGPPET[,7])),rep("K2 NEG",length(CORR_K2_TRW_NEGPPET[,7])),
rep("L1 NEG",length(CORR_L1_TRW_NEGPPET[,7])),rep("L2 NEG",length(CORR_L2_TRW_NEGPPET[,7]))))

ids_RUS1_TRW<-as.matrix(c(
rep("U1 POS",length(CORR_U1_TRW_POSPPET[,7])),rep("U2 POS",length(CORR_U2_TRW_POSPPET[,7])),
rep("O1 POS",length(CORR_O1_TRW_POSPPET[,7])),rep("O2 POS",length(CORR_O2_TRW_POSPPET[,7])),
rep("U1 NEG",length(CORR_U1_TRW_NEGPPET[,7])),rep("U2 NEG",length(CORR_U2_TRW_NEGPPET[,7])),
rep("O1 NEG",length(CORR_O1_TRW_NEGPPET[,7])),rep("O2 NEG",length(CORR_O2_TRW_NEGPPET[,7]))))

ids_RUS2_TRW<-as.matrix(c(
rep("H1 POS",length(CORR_H1_TRW_POSPPET[,7])),rep("H2 POS",length(CORR_H2_TRW_POSPPET[,7])),
rep("G1 POS",length(CORR_G1_TRW_POSPPET[,7])),rep("G2 POS",length(CORR_G2_TRW_POSPPET[,7])),
rep("H1 NEG",length(CORR_H1_TRW_NEGPPET[,7])),rep("H2 NEG",length(CORR_H2_TRW_NEGPPET[,7])),
rep("G1 NEG",length(CORR_G1_TRW_NEGPPET[,7])),rep("G2 NEG",length(CORR_G2_TRW_NEGPPET[,7]))))

out_WILCOX_FIN_TRW<-pairwise.wilcox.test(anovadata_FIN_TRW,as.factor(ids_FIN_TRW),method="holm")
out_WILCOX_RUS1_TRW<-pairwise.wilcox.test(anovadata_RUS1_TRW,as.factor(ids_RUS1_TRW),method="holm")
out_WILCOX_RUS2_TRW<-pairwise.wilcox.test(anovadata_RUS2_TRW,as.factor(ids_RUS2_TRW),method="holm")








##################################################################################################
# (XII)	plot Figures 3 and 4



### Figure 3 (MXD)

# plot correlations of individual trees
par(mar = c(10,6,4,2) + 0.1)
boxplot(CORR_K1_MXD_POSPPET[,1],CORR_K1_MXD_NEGPPET[,1],CORR_K2_MXD_POSPPET[,1],CORR_K2_MXD_NEGPPET[,1],CORR_L1_MXD_POSPPET[,1],CORR_L1_MXD_NEGPPET[,1],CORR_L2_MXD_POSPPET[,1],
CORR_L2_MXD_NEGPPET[,1],NA,CORR_U1_MXD_POSPPET[,1],CORR_U1_MXD_NEGPPET[,1],CORR_U2_MXD_POSPPET[,1],CORR_U2_MXD_NEGPPET[,1],
CORR_O1_MXD_POSPPET[,1],CORR_O1_MXD_NEGPPET[,1],CORR_O2_MXD_POSPPET[,1],CORR_O2_MXD_NEGPPET[,1],NA,CORR_H1_MXD_POSPPET[,1],CORR_H1_MXD_NEGPPET[,1],CORR_H2_MXD_POSPPET[,1],
CORR_H2_MXD_NEGPPET[,1],CORR_G1_MXD_POSPPET[,1],CORR_G1_MXD_NEGPPET[,1],CORR_G2_MXD_POSPPET[,1],CORR_G2_MXD_NEGPPET[,1],
ylim=c(-0.5,0.8),
names=c("TD: wet/cold","TD: dry/warm","TW: wet/cold","TW: dry/warm","FD: wet/cold","FD: dry/warm","FW: wet/cold","FW: dry/warm",NA,
"TD: wet/cold","TD: dry/warm","TW: wet/cold","TW: dry/warm","FD: wet/cold","FD: dry/warm","FW: wet/cold","FW: dry/warm",NA,
"TD: wet/cold","TD: dry/warm","TW: wet/cold","TW: dry/warm","FD: wet/cold","FD: dry/warm","FW: wet/cold","FW: dry/warm"),
col=c("red","red","blue","blue","orange","orange","dodgerblue","dodgerblue",NA,"red","red","blue","blue","orange","orange","dodgerblue","dodgerblue",NA,
"red","red","blue","blue","orange","orange","dodgerblue","dodgerblue"),las=2,ylab=NA,lwd=0.8,cex=0.7,cex.axis=0.9)

title(ylab="correlation coefficient",line=4,cex=0.8)

# add corr. of the chrono
lines(unlist(corr_K1_MXD_TEMP_POSPPET[2])[74]~1,type="p",lwd=2,col="black",bg="red",pch=21,cex=2)
lines(unlist(corr_K2_MXD_TEMP_POSPPET[2])[74]~c(1+2),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_L1_MXD_TEMP_POSPPET[2])[74]~c(1+4),type="p",lwd=2,col="black",bg="orange",pch=21,cex=2)
lines(unlist(corr_L2_MXD_TEMP_POSPPET[2])[74]~c(1+6),type="p",lwd=2,col="black",bg="dodgerblue",pch=21,cex=2)
lines(unlist(corr_U1_MXD_TEMP_POSPPET[2])[74]~c(1+9),type="p",lwd=2,col="black",bg="red",pch=21,cex=2)
lines(unlist(corr_U2_MXD_TEMP_POSPPET[2])[74]~c(1+11),type="p",lwd=2,col="black",bg="blue",pch=21,cex=2)
lines(unlist(corr_O1_MXD_TEMP_POSPPET[2])[74]~c(1+13),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_O2_MXD_TEMP_POSPPET[2])[74]~c(1+15),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_H1_MXD_TEMP_POSPPET[2])[74]~c(1+18),type="p",lwd=2,col="black",bg="red",pch=21,cex=2)
lines(unlist(corr_H2_MXD_TEMP_POSPPET[2])[74]~c(1+20),type="p",lwd=2,col="black",bg="blue",pch=21,cex=2)
lines(unlist(corr_G1_MXD_TEMP_POSPPET[2])[74]~c(1+22),type="p",lwd=2,col="black",bg="orange",pch=21,cex=2)
lines(unlist(corr_G2_MXD_TEMP_POSPPET[2])[74]~c(1+24),type="p",lwd=2,col="black",bg="dodgerblue",pch=21,cex=2)

lines(unlist(corr_K1_MXD_TEMP_NEGPPET[2])[74]~c(1+1),type="p",lwd=2,col="black",bg="red",pch=21,cex=2)
lines(unlist(corr_K2_MXD_TEMP_NEGPPET[2])[74]~c(1+3),type="p",lwd=2,col="black",bg="blue",pch=21,cex=2)
lines(unlist(corr_L1_MXD_TEMP_NEGPPET[2])[74]~c(1+5),type="p",lwd=2,col="black",bg="orange",pch=21,cex=2)
lines(unlist(corr_L2_MXD_TEMP_NEGPPET[2])[74]~c(1+7),type="p",lwd=2,col="black",bg="dodgerblue",pch=21,cex=2)
lines(unlist(corr_U1_MXD_TEMP_NEGPPET[2])[74]~c(1+10),type="p",lwd=2,col="black",bg="red",pch=21,cex=2)
lines(unlist(corr_U2_MXD_TEMP_NEGPPET[2])[74]~c(1+12),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_O1_MXD_TEMP_NEGPPET[2])[74]~c(1+14),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_O2_MXD_TEMP_NEGPPET[2])[74]~c(1+16),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_H1_MXD_TEMP_NEGPPET[2])[74]~c(1+19),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_H2_MXD_TEMP_NEGPPET[2])[74]~c(1+21),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_G1_MXD_TEMP_NEGPPET[2])[74]~c(1+23),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_G2_MXD_TEMP_NEGPPET[2])[74]~c(1+25),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)

# significant difference obtained from wilcox test
lines(c(rep(-0.5,18))~c(1.25,1.5,1.75,3.5,10.3,10.6,19.25,19.5,19.75,21.25,21.5,21.75,23.25,23.5,23.75,25.25,25.5,25.75),type="p",pch=c("***","*","**","***","***","***","***"),cex=0.9)

abline(0,0,lty=2,lwd=0.8)
abline(v=9)
abline(v=18)






### Figure 4 (TRW)

# plot correlations of individual trees
par(mar = c(10,6,4,2) + 0.1)
boxplot(CORR_K1_TRW_POSPPET[,7],CORR_K1_TRW_NEGPPET[,7],CORR_K2_TRW_POSPPET[,7],CORR_K2_TRW_NEGPPET[,7],CORR_L1_TRW_POSPPET[,7],CORR_L1_TRW_NEGPPET[,7],CORR_L2_TRW_POSPPET[,7],
CORR_L2_TRW_NEGPPET[,7],NA, CORR_U1_TRW_POSPPET[,7],CORR_U1_TRW_NEGPPET[,7],CORR_U2_TRW_POSPPET[,7],CORR_U2_TRW_NEGPPET[,7],
CORR_O1_TRW_POSPPET[,7],CORR_O1_TRW_NEGPPET[,7],CORR_O2_TRW_POSPPET[,7],CORR_O2_TRW_NEGPPET[,7],NA,CORR_H1_TRW_POSPPET[,7],CORR_H1_TRW_NEGPPET[,7],CORR_H2_TRW_POSPPET[,7],
CORR_H2_TRW_NEGPPET[,7],CORR_G1_TRW_POSPPET[,7],CORR_G1_TRW_NEGPPET[,7],CORR_G2_TRW_POSPPET[,7],CORR_G2_TRW_NEGPPET[,7],
ylim=c(-0.5,0.8),
names=c("TD: wet/cold","TD: dry/warm","TW: wet/cold","TW: dry/warm","FD: wet/cold","FD: dry/warm","FW: wet/cold","FW: dry/warm",NA,
"TD: wet/cold","TD: dry/warm","TW: wet/cold","TW: dry/warm","FD: wet/cold","FD: dry/warm","FW: wet/cold","FW: dry/warm",NA,
"TD: wet/cold","TD: dry/warm","TW: wet/cold","TW: dry/warm","FD: wet/cold","FD: dry/warm","FW: wet/cold","FW: dry/warm"),
col=c("red","red","blue","blue","orange","orange","dodgerblue","dodgerblue",NA,"red","red","blue","blue","orange","orange","dodgerblue","dodgerblue",NA,
"red","red","blue","blue","orange","orange","dodgerblue","dodgerblue"),las=2,ylab=NA,lwd=0.8,cex=0.7,cex.axis=0.9)

title(ylab="correlation coefficient",line=4,cex=0.8)

# add corr. of the chrono
lines(unlist(corr_K1_TRW_TEMP_POSPPET[2])[71]~1,type="p",lwd=2,col="black",bg="red",pch=21,cex=2)
lines(unlist(corr_K2_TRW_TEMP_POSPPET[2])[71]~c(1+2),type="p",lwd=2,col="black",bg="blue",pch=21,cex=2)
lines(unlist(corr_L1_TRW_TEMP_POSPPET[2])[71]~c(1+4),type="p",lwd=2,col="black",bg="orange",pch=21,cex=2)
lines(unlist(corr_L2_TRW_TEMP_POSPPET[2])[71]~c(1+6),type="p",lwd=2,col="black",bg="dodgerblue",pch=21,cex=2)
lines(unlist(corr_U1_TRW_TEMP_POSPPET[2])[71]~c(1+9),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_U2_TRW_TEMP_POSPPET[2])[71]~c(1+11),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_O1_TRW_TEMP_POSPPET[2])[71]~c(1+13),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_O2_TRW_TEMP_POSPPET[2])[71]~c(1+15),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_H1_TRW_TEMP_POSPPET[2])[71]~c(1+18),type="p",lwd=2,col="black",bg="red",pch=21,cex=2)
lines(unlist(corr_H2_TRW_TEMP_POSPPET[2])[71]~c(1+20),type="p",lwd=2,col="black",bg="blue",pch=21,cex=2)
lines(unlist(corr_G1_TRW_TEMP_POSPPET[2])[71]~c(1+22),type="p",lwd=2,col="black",bg="orange",pch=21,cex=2)
lines(unlist(corr_G2_TRW_TEMP_POSPPET[2])[71]~c(1+24),type="p",lwd=2,col="black",bg="dodgerblue",pch=21,cex=2)

lines(unlist(corr_K1_TRW_TEMP_NEGPPET[2])[71]~c(1+1),type="p",lwd=2,col="black",bg="red",pch=21,cex=2)
lines(unlist(corr_K2_TRW_TEMP_NEGPPET[2])[71]~c(1+3),type="p",lwd=2,col="black",bg="blue",pch=21,cex=2)
lines(unlist(corr_L1_TRW_TEMP_NEGPPET[2])[71]~c(1+5),type="p",lwd=2,col="black",bg="orange",pch=21,cex=2)
lines(unlist(corr_L2_TRW_TEMP_NEGPPET[2])[71]~c(1+7),type="p",lwd=2,col="black",bg="dodgerblue",pch=21,cex=2)
lines(unlist(corr_U1_TRW_TEMP_NEGPPET[2])[71]~c(1+10),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_U2_TRW_TEMP_NEGPPET[2])[71]~c(1+12),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_O1_TRW_TEMP_NEGPPET[2])[71]~c(1+14),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_O2_TRW_TEMP_NEGPPET[2])[71]~c(1+16),type="p",lwd=2,col="black",bg="dodgerblue",pch=21,cex=2)
lines(unlist(corr_H1_TRW_TEMP_NEGPPET[2])[71]~c(1+19),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_H2_TRW_TEMP_NEGPPET[2])[71]~c(1+21),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_G1_TRW_TEMP_NEGPPET[2])[71]~c(1+23),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)
lines(unlist(corr_G2_TRW_TEMP_NEGPPET[2])[71]~c(1+25),type="p",lwd=2,col="black",bg="grey",pch=21,cex=2)

# significant difference obtained from wilcox test
lines(c(rep(-0.5,14))~c(5.3,5.6,19.25,19.5,19.75,21.25,21.5,21.75,23.25,23.5,23.75,25.25,25.5,25.75),
type="p",pch=c("*","**","***","***","***","***"),cex=0.9)

abline(0,0,lty=2,lwd=0.8)
abline(v=9)
abline(v=18)



